===============================
Community.Libvirt Release Notes
===============================

.. contents:: Topics


v1.0.0
======

Major Changes
-------------

- added generic libvirt inventory plugin
- removed libvirt_lxc inventory script
